@@ -11,7 +11,7 @@ License: Public Domain
 import hxl_proxy
 from hxl.io import HXLIOException
 
-from hxl_proxy import admin, app, auth, cache, dao, exceptions, filters, pcodes, preview, recipes, util, validate
+from hxl_proxy import admin, app, auth, cache, caching, dao, exceptions, filters, pcodes, preview, recipes, util, validate
 
 import datetime, flask, hxl, io, json, logging, requests, requests_cache, werkzeug, csv, urllib
 
@@ -552,11 +552,7 @@ def data_view(recipe_id=None, format="html", stub=None, flavour=None):
         if util.skip_cache_p():
             source = filters.setup_filters(recipe)
         else:
-            with requests_cache.enabled(
-                    app.config.get('REQUEST_CACHE_NAME', 'hxl-proxy-in'),
-                    backend=app.config.get('REQUEST_CACHE_BACKEND', 'memory'),
-                    expire_after=app.config.get('REQUEST_CACHE_TIMEOUT', 3600)
-            ):
+            with caching.input():
                 source = filters.setup_filters(recipe)
 
         # Parameters controlling the output
@@ -1351,11 +1347,7 @@ def data_preview (format="json"):
     if util.skip_cache_p():
         input = hxl.io.make_input(url, sheet_index=sheet)
     else:
-        with requests_cache.enabled(
-                app.config.get('REQUEST_CACHE_NAME', 'hxl-proxy-in'),
-                backend=app.config.get('REQUEST_CACHE_BACKEND', 'memory'),
-                expire_after=app.config.get('REQUEST_CACHE_TIMEOUT', 3600)
-        ):
+        with caching.input():
             input = hxl.io.make_input(url, sheet_index=sheet)
 
     # Generate result
@@ -1431,10 +1423,7 @@ def data_preview_sheets(format="json"):
             if util.skip_cache_p():
                 input = hxl.io.make_input(url, sheet_index=sheet)
             else:
-                with requests_cache.enabled(
-                        app.config.get('REQUEST_CACHE', '/tmp/hxl_proxy_requests'),
-                        expire_after=app.config.get('REQUEST_CACHE_TIMEOUT_SECONDS', 3600)
-                ):
+                with caching.input():
                     input = hxl.io.make_input(url, sheet_index=sheet)
             if isinstance(input, hxl.io.CSVInput):
                 _output.append("Default")
